==> thx-sphinx-0.4.1.tar.gz: thx-sphinx-0.4.1/thx/sphinx/docs.py <==
# coding: utf-8
"""
Documentation
=============


Documentation is written with Sphinx...

"""


def get_jumbo_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for jumbo theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":"
    return ("Jumbo", {
        'sub': [
            ('Framework', {'ref': '{}index'.format(app_label)}),
            ('--', ''),
            ('Quickstart', {'ref': '{}quickstart'.format(app_label)}),
            ('Buildout', {'ref': '{}buildout-env'.format(app_label)}),
            ('Utils', {'ref': '{}buildout-utilities'.format(app_label)}),
            ('Mercurial', {'ref': 'mercurial'.format(app_label)}),
            ('Troubleshooting', {'ref': '{}troubleshooting'.format(app_label)}),
            ('--', ''),
            ('Writing Documentation', {'ref': '{}use-sphinx'.format(app_label)}),
        ]
    })


def get_packages_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for jumbo theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":"
    return ("Packages", {
        'sub': [
            ('jmb.core', {'href': 'http://docs.thux.it/jmb.core', 'static': True}),
            ('jmb.jadmin', {'href': 'http://docs.thux.it/jmb.jadmin', 'static': True}),
            ('jmb.filters', {'href': 'http://docs.thux.it/jmb.filters', 'static': True}),
            ('docs', {'href': 'http://docs.thux.it/thx-docs', 'static': True}),
            ('--', ''),
            ('jmb.async', {'href': 'http://docs.thux.it/jmb.async', 'static': True}),
            ('jmb.fax', {'href': 'http://docs.thux.it/jmb.fax', 'static': True}),
            ('jmb.ticket', {'href': 'http://docs.thux.it/jmb.ticket', 'static': True}),
            #            ('jmb.news', {'href' : 'http://docs.thux.it/jmb.news', 'static':True}),
            ('jmb.webposte', {'href': 'http://docs.thux.it/jmb.webposte', 'static': True}),
            ('jmb.newsletter', {'href': 'http://docs.thux.it/jmb.newsletter', 'static': True}),
            ('--', ''),
            ('poste-online', {'href': 'http://docs.thux.it/poste-online', 'static': True}),
        ]
    })

==> thx-sphinx-0.4.4.tar.gz: thx-sphinx-0.4.4/thx/sphinx/docs.py <==
# coding: utf-8
"""
Documentation
=============


Documentation is written with Sphinx...

"""


def get_jumbo_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for jumbo theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":"
    return ("Jumbo", {
        'sub': [
            ('Framework', {'ref': '{}index'.format(app_label)}),
            ('--', ''),
            ('Quickstart', {'ref': '{}quickstart'.format(app_label)}),
            ('Buildout', {'ref': '{}buildout-env'.format(app_label)}),
            ('Utils', {'ref': '{}buildout-utilities'.format(app_label)}),
            ('Mercurial', {'ref': '{}Mercurial'.format(app_label)}),
            ('Troubleshooting', {'ref': '{}troubleshooting'.format(app_label)}),
            ('--', ''),
            ('Writing Documentation', {'ref': '{}use-sphinx'.format(app_label)}),
        ]
    })


def get_packages_menu_entry(app_label=''):
    """Return a tuple suitable as dropdown specification for jumbo theme

    :arg app_label: an app_label suitable for intersphinx specs
    """
    if app_label:
        app_label = app_label + ":"
    return ("Packages", {
        'sub': [
            ('jmb.core', {'href': 'http://docs.thux.it/jmb.core', 'static': True}),
            ('jmb.jadmin', {'href': 'http://docs.thux.it/jmb.jadmin', 'static': True}),
            ('jmb.filters', {'href': 'http://docs.thux.it/jmb.filters', 'static': True}),
            ('--', ''),
            ('jmb.async', {'href': 'http://docs.thux.it/jmb.async', 'static': True}),
            ('jmb.fax', {'href': 'http://docs.thux.it/jmb.fax', 'static': True}),
            ('jmb.ticket', {'href': 'http://docs.thux.it/jmb.ticket', 'static': True}),
            #            ('jmb.news', {'href' : 'http://docs.thux.it/jmb.news', 'static':True}),
            ('jmb.webposte', {'href': 'http://docs.thux.it/jmb.webposte', 'static': True}),
            ('jmb.newsletter', {'href': 'http://docs.thux.it/jmb.newsletter', 'static': True}),
            ('--', ''),
            ('poste-online', {'href': 'http://docs.thux.it/poste-online', 'static': True}),
        ]
    })
